====================================
Translating the SQUAD user interface
====================================

The SQUAD translations are kindly hosted by Weblate_.

.. _Weblate: https://hosted.weblate.org/

The translations are split into different components, which match the separate
modules in the squad codebase. As of this writing, we have the components
`core` and `frontend`. When you are reading this, we could have others.

In order to work with SQUAD translations, you need to create a weblate account.

To translate SQUAD into your language, just go to the `project page on
weblate`_, click on the component you want, and then click on your language.

.. _`project page on weblate`: https://hosted.weblate.org/projects/squad/

If your language does not exist yet for that component, just click "Start new
translation".

Translation updates made on weblate are sent back to the SQUAD source code
repository once a day.
